@@ -21,6 +21,15 @@
 
 #include <string.h>
 
+#ifndef HAVE_GETLINE
+#if !(__STDC_VERSION__ >= 199901L)
+#define restrict
+#endif
+ssize_t
+seg_getline(char ** restrict linep, size_t * restrict linecapp, FILE * restrict stream);
+#define getline(l,c,s) seg_getline(l,c,s)
+#endif
+
 #define SEGPbsEnter() \
         SEGPbsDebug(SEG_PBS_DEBUG_INFO, ("Enter %s\n", _globus_func_name))
 
@@ -504,7 +513,9 @@ globus_l_pbs_read_callback(
             case EIO:           /* STREAMS-related */
             case EISDIR:        /* Can only happen when open for write to a dir
                                  */
+#ifdef ENOSR
             case ENOSR:         /* STREAMS-related */
+#endif
             case ENOSPC:        /* Can only happen when creating file */
             case ENXIO:         /* nonblocking write to a fifo with no reader */
             case EROFS:         /* write to readonly filesystem */
